intelmq.bots.experts.jinja namespace — intelmq 3.1.0.alpha1 documentation

# intelmq.bots.experts.jinja namespace

## Submodules

## intelmq.bots.experts.jinja.expert module

intelmq.bots.experts.jinja.expert.BOT

  alias of `intelmq.bots.experts.jinja.expert.JinjaExpertBot`

class intelmq.bots.experts.jinja.expert.JinjaExpertBot(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.Bot`

  Modify the message using the Jinja templating engine Example: fields:

  > output: The provider is {{ msg[‘feed.provider’] }}! feed.url: “{{ msg[‘feed.url’] | upper }}” extra.somejinjaoutput: file:///etc/intelmq/somejinjatemplate.j2

  fields: Dict[str, Union[str, jinja2.environment.Template]] = {}
  init()
  overwrite: bool = False
  process()